NICMOS ImageObjects — drizzlepac 1.0.6 (14-Aug-2012) documentation

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »
- imageObject Classes »

# NICMOS ImageObjects

class `drizzlepac.nicmosData.` `NICMOSInputImage`(filename=None)

  Bases: `drizzlepac.imageObject.imageObject`

  `doUnitConversions`()

    Convert the data to electrons

    This converts all science data extensions and saves the results back to disk. We need to make sure the data inside the chips already in memory is altered as well.

  `getdarkcurrent`()

    Return the dark current for the NICMOS detectors.

    Returns :
    | darkcurrent : float Dark current value with units of cps.

  `getdarkimg`(chip)

    Return an array representing the dark image for the detector.

    Returns :
    | dark : array The dark array in the same shape as the image with units of cps.

  `getexptimeimg`(chip)

    Return an array representing the exposure time per pixel for the detector.

    Returns :
    | dark: array : Exposure time array in the same shape as the input image

  `getflat`(chip)

    Method for retrieving a detector’s flat field.

    Returns :
    | flat : array The flat field array in the same shape as the input image with units of cps.

  `isCountRate`()

    isCountRate: Method or IRInputObject used to indicate if the science data is in units of counts or count rate. This method assumes that the keyword ‘BUNIT’ is in the header of the input FITS file.

  `SEPARATOR` = '_'

class `drizzlepac.nicmosData.` `NIC1InputImage`(filename=None)

  Bases: `drizzlepac.nicmosData.NICMOSInputImage`

  `setInstrumentParameters`(instrpars)

    This method overrides the superclass to set default values into the parameter dictionary, in case empty entries are provided.

class `drizzlepac.nicmosData.` `NIC2InputImage`(filename=None)

  Bases: `drizzlepac.nicmosData.NICMOSInputImage`

  `createHoleMask`()

    Add in a mask for the coronographic hole to the general static pixel mask.

  `setInstrumentParameters`(instrpars)

    This method overrides the superclass to set default values into the parameter dictionary, in case empty entries are provided.

class `drizzlepac.nicmosData.` `NIC3InputImage`(filename=None)

  Bases: `drizzlepac.nicmosData.NICMOSInputImage`

  `setInstrumentParameters`(instrpars)

    This method overrides the superclass to set default values into the parameter dictionary, in case empty entries are provided.

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »
- imageObject Classes »